# pydatavolley

A python package for reading volleyball scouting files in DataVolley
format (\*.dvw).

### Installation

    pip install pydatavolley

### Example

Example file will read if no path is provided:

``` python
from datavolley import read_dv

dv_instance = read_dv.DataVolley(None)
df = dv_instance.get_plays()
df.head(40)
```

<div>
<style scoped>
    .dataframe tbody tr th:only-of-type {
        vertical-align: middle;
    }
&#10;    .dataframe tbody tr th {
        vertical-align: top;
    }
&#10;    .dataframe thead th {
        text-align: right;
    }
</style>

|     | code                    | point_phase | attack_phase | start_coordinate | mid_coordainte | end_coordainte | time | set | home_setter_position | visiting_setter_position | ... | visiting_team_id | start_zone | end_zone | end_subzone | rally_number | point_won_by             | home_team_score | visiting_team_score | serving_team             | receiving_team           |
|-----|-------------------------|-------------|--------------|------------------|----------------|----------------|------|-----|----------------------|--------------------------|-----|------------------|------------|----------|-------------|--------------|--------------------------|-----------------|---------------------|--------------------------|--------------------------|
| 0   | \*P19\>LUp              | NaN         | NaN          | NaN              | NaN            | NaN            | NaN  | 1   | 1                    | 6                        | ... | 42               | NaN        | NaN      | NaN         | 0            | NaN                      | NaN             | NaN                 | NaN                      | University of Louisville |
| 1   | \*z1\>LUp               | NaN         | NaN          | NaN              | NaN            | NaN            | NaN  | 1   | 1                    | 6                        | ... | 42               | NaN        | NaN      | NaN         | 0            | NaN                      | NaN             | NaN                 | NaN                      | University of Louisville |
| 2   | aP08\>LUp               | NaN         | NaN          | NaN              | NaN            | NaN            | NaN  | 1   | 1                    | 6                        | ... | 42               | NaN        | NaN      | NaN         | 0            | NaN                      | NaN             | NaN                 | NaN                      | University of Louisville |
| 3   | az6\>LUp                | NaN         | NaN          | NaN              | NaN            | NaN            | NaN  | 1   | 1                    | 6                        | ... | 42               | NaN        | NaN      | NaN         | 0            | NaN                      | NaN             | NaN                 | NaN                      | University of Louisville |
| 4   | \*19SM+\~\~~78A\~\~~00  | NaN         | NaN          | 0431             | NaN            | 7642           | NaN  | 1   | 1                    | 6                        | ... | 42               | 7          | 8        | A           | 1            | University of Louisville | 01              | 00                  | University of Louisville | University of Dayton     |
| 5   | a02RM-\~\~~58AM\~~00B   | NaN         | NaN          | 0431             | NaN            | 7642           | NaN  | 1   | 1                    | 6                        | ... | 42               | 5          | 8        | A           | 1            | University of Louisville | 01              | 00                  | University of Louisville | University of Dayton     |
| 6   | a08ET#\~\~\~~8C\~\~~00  | NaN         | NaN          | 3147             | NaN            | NaN            | NaN  | 1   | 1                    | 6                        | ... | 42               | NaN        | 8        | C           | 1            | University of Louisville | 01              | 00                  | University of Louisville | University of Dayton     |
| 7   | a10AT-X5~46CH2~00F      | NaN         | NaN          | 4512             | 5522           | 8150           | NaN  | 1   | 1                    | 6                        | ... | 42               | 4          | 6        | C           | 1            | University of Louisville | 01              | 00                  | University of Louisville | University of Dayton     |
| 8   | \*11BT+\~\~\~~2C\~\~~00 | NaN         | NaN          | 4578             | NaN            | NaN            | NaN  | 1   | 1                    | 6                        | ... | 42               | NaN        | 2        | C           | 1            | University of Louisville | 01              | 00                  | University of Louisville | University of Dayton     |
| 9   | \*19DT+\~\~~42AB\~~00B  | NaN         | NaN          | 4512             | 5522           | 5912           | NaN  | 1   | 1                    | 6                        | ... | 42               | 4          | 2        | A           | 1            | University of Louisville | 01              | 00                  | University of Louisville | University of Dayton     |
| 10  | \*08EH#\~\~\~~8A\~\~~00 | NaN         | NaN          | 2859             | NaN            | NaN            | NaN  | 1   | 1                    | 6                        | ... | 42               | NaN        | 8        | A           | 1            | University of Louisville | 01              | 00                  | University of Louisville | University of Dayton     |
| 11  | \*09AH#V5~41BH2~00F     | NaN         | NaN          | 4316             | 5517           | 7918           | NaN  | 1   | 1                    | 6                        | ... | 42               | 4          | 1        | B           | 1            | University of Louisville | 01              | 00                  | University of Louisville | University of Dayton     |
| 12  | a17BH=\~\~\~~2B\~\~~00  | NaN         | NaN          | 4583             | NaN            | NaN            | NaN  | 1   | 1                    | 6                        | ... | 42               | NaN        | 2        | B           | 1            | University of Louisville | 01              | 00                  | University of Louisville | University of Dayton     |
| 13  | \*p01:00                | NaN         | NaN          | 4493             | NaN            | NaN            | NaN  | 1   | 1                    | 6                        | ... | 42               | NaN        | NaN      | NaN         | 1            | University of Louisville | 01              | 00                  | University of Louisville | University of Dayton     |
| 14  | \*P19                   | NaN         | NaN          | NaN              | NaN            | NaN            | NaN  | 1   | 1                    | 6                        | ... | 42               | NaN        | NaN      | NaN         | 1            | University of Louisville | NaN             | NaN                 | University of Louisville | University of Dayton     |
| 15  | \*z1                    | NaN         | NaN          | NaN              | NaN            | NaN            | NaN  | 1   | 1                    | 6                        | ... | 42               | NaN        | NaN      | NaN         | 1            | University of Louisville | NaN             | NaN                 | University of Louisville | University of Dayton     |
| 16  | aP08                    | NaN         | NaN          | NaN              | NaN            | NaN            | NaN  | 1   | 1                    | 6                        | ... | 42               | NaN        | NaN      | NaN         | 1            | University of Louisville | NaN             | NaN                 | University of Louisville | University of Dayton     |
| 17  | az6                     | NaN         | NaN          | NaN              | NaN            | NaN            | NaN  | 1   | 1                    | 6                        | ... | 42               | NaN        | NaN      | NaN         | 1            | University of Louisville | NaN             | NaN                 | University of Louisville | University of Dayton     |
| 18  | \*19SM#\~\~~71C\~\~~+1  | NaN         | NaN          | 0529             | NaN            | 7728           | NaN  | 1   | 1                    | 6                        | ... | 42               | 7          | 1        | C           | 2            | University of Louisville | 02              | 00                  | University of Louisville | University of Dayton     |
| 19  | a01RM=\~\~~51CM\~~-1B   | NaN         | NaN          | 0529             | NaN            | 7728           | NaN  | 1   | 1                    | 6                        | ... | 42               | 5          | 1        | C           | 2            | University of Louisville | 02              | 00                  | University of Louisville | University of Dayton     |
| 20  | \*p02:00                | NaN         | NaN          | 4293             | NaN            | NaN            | NaN  | 1   | 1                    | 6                        | ... | 42               | NaN        | NaN      | NaN         | 2            | University of Louisville | 02              | 00                  | University of Louisville | University of Dayton     |
| 21  | \*P19                   | NaN         | NaN          | NaN              | NaN            | NaN            | NaN  | 1   | 1                    | 6                        | ... | 42               | NaN        | NaN      | NaN         | 2            | University of Louisville | NaN             | NaN                 | University of Louisville | University of Dayton     |
| 22  | \*z1                    | NaN         | NaN          | NaN              | NaN            | NaN            | NaN  | 1   | 1                    | 6                        | ... | 42               | NaN        | NaN      | NaN         | 2            | University of Louisville | NaN             | NaN                 | University of Louisville | University of Dayton     |
| 23  | aP08                    | NaN         | NaN          | NaN              | NaN            | NaN            | NaN  | 1   | 1                    | 6                        | ... | 42               | NaN        | NaN      | NaN         | 2            | University of Louisville | NaN             | NaN                 | University of Louisville | University of Dayton     |
| 24  | az6                     | NaN         | NaN          | NaN              | NaN            | NaN            | NaN  | 1   | 1                    | 6                        | ... | 42               | NaN        | NaN      | NaN         | 2            | University of Louisville | NaN             | NaN                 | University of Louisville | University of Dayton     |
| 25  | \*19SM-\~\~~71C\~\~~+2  | NaN         | NaN          | 0526             | NaN            | 7728           | NaN  | 1   | 1                    | 6                        | ... | 42               | 7          | 1        | C           | 3            | University of Louisville | 03              | 00                  | University of Louisville | University of Dayton     |
| 26  | a01RM+\~\~~51CR\~~-2B   | NaN         | NaN          | 0526             | NaN            | 7728           | NaN  | 1   | 1                    | 6                        | ... | 42               | 5          | 1        | C           | 3            | University of Louisville | 03              | 00                  | University of Louisville | University of Dayton     |
| 27  | a08EQ#K1C~3A\~\~~-2     | NaN         | NaN          | 4252             | NaN            | NaN            | NaN  | 1   | 1                    | 6                        | ... | 42               | NaN        | 3        | A           | 3            | University of Louisville | 03              | 00                  | University of Louisville | University of Dayton     |
| 28  | a16AQ=X1~31AH1~-2F      | NaN         | NaN          | 4444             | NaN            | 8913           | NaN  | 1   | 1                    | 6                        | ... | 42               | 3          | 1        | A           | 3            | University of Louisville | 03              | 00                  | University of Louisville | University of Dayton     |
| 29  | \*p03:00                | NaN         | NaN          | 1187             | NaN            | NaN            | NaN  | 1   | 1                    | 6                        | ... | 42               | NaN        | NaN      | NaN         | 3            | University of Louisville | 03              | 00                  | University of Louisville | University of Dayton     |
| 30  | \*P19                   | NaN         | NaN          | NaN              | NaN            | NaN            | NaN  | 1   | 1                    | 6                        | ... | 42               | NaN        | NaN      | NaN         | 3            | University of Louisville | NaN             | NaN                 | University of Louisville | University of Dayton     |
| 31  | \*z1                    | NaN         | NaN          | NaN              | NaN            | NaN            | NaN  | 1   | 1                    | 6                        | ... | 42               | NaN        | NaN      | NaN         | 3            | University of Louisville | NaN             | NaN                 | University of Louisville | University of Dayton     |
| 32  | aP08                    | NaN         | NaN          | NaN              | NaN            | NaN            | NaN  | 1   | 1                    | 6                        | ... | 42               | NaN        | NaN      | NaN         | 3            | University of Louisville | NaN             | NaN                 | University of Louisville | University of Dayton     |
| 33  | az6                     | NaN         | NaN          | NaN              | NaN            | NaN            | NaN  | 1   | 1                    | 6                        | ... | 42               | NaN        | NaN      | NaN         | 3            | University of Louisville | NaN             | NaN                 | University of Louisville | University of Dayton     |
| 34  | \*19SM#\~\~~71B\~\~~+3  | NaN         | NaN          | 0527             | NaN            | 8017           | NaN  | 1   | 1                    | 6                        | ... | 42               | 7          | 1        | B           | 4            | University of Louisville | 04              | 00                  | University of Louisville | University of Dayton     |
| 35  | a01RM=\~\~~51BL\~~-3B   | NaN         | NaN          | 0527             | NaN            | 8017           | NaN  | 1   | 1                    | 6                        | ... | 42               | 5          | 1        | B           | 4            | University of Louisville | 04              | 00                  | University of Louisville | University of Dayton     |
| 36  | \*p04:00                | NaN         | NaN          | -113             | NaN            | NaN            | NaN  | 1   | 1                    | 6                        | ... | 42               | NaN        | NaN      | NaN         | 4            | University of Louisville | 04              | 00                  | University of Louisville | University of Dayton     |
| 37  | \*P19                   | NaN         | NaN          | NaN              | NaN            | NaN            | NaN  | 1   | 1                    | 6                        | ... | 42               | NaN        | NaN      | NaN         | 4            | University of Louisville | NaN             | NaN                 | University of Louisville | University of Dayton     |
| 38  | \*z1                    | NaN         | NaN          | NaN              | NaN            | NaN            | NaN  | 1   | 1                    | 6                        | ... | 42               | NaN        | NaN      | NaN         | 4            | University of Louisville | NaN             | NaN                 | University of Louisville | University of Dayton     |
| 39  | aP08                    | NaN         | NaN          | NaN              | NaN            | NaN            | NaN  | 1   | 1                    | 6                        | ... | 42               | NaN        | NaN      | NaN         | 4            | University of Louisville | NaN             | NaN                 | University of Louisville | University of Dayton     |

<p>40 rows × 45 columns</p>
</div>
